@@ -1,15 +1,15 @@
 # -*-mode: tcl; fill-column: 75; tab-width: 8; coding: iso-latin-1-unix -*-
 #
-#       $Id: Menu.tcl,v 1.14 2004/03/28 07:56:07 vvzhy Exp $
+#       $Id: Menu.tcl,v 1.16.2.1 2005/09/30 15:26:26 robert_dodier Exp $
 #
 
 proc pMAXSaveTexToFile {text} {
-    set file [tide_savefile [M "Save to a file"] "" *.out]
+    set file [tide_savefile [M [mc "Save to a file"]] "" *.out]
     if {$file != ""} {
 	set contents [$text get 1.0 end]
 	set fd [open $file w]
 	if {[catch {puts $fd $contents} err]} {
-	    tide_failure [M "Error writing to file:\n%s" $err]
+	    tide_failure [M [mc "Error writing to file:\n%s"] $err]
 	}
 	catch {close $fd}
     }
@@ -29,38 +29,38 @@ proc vMAXAddSystemMenu {fr text} {
 
     # Add a File menubutton
     set m [menu .menu.file -tearoff 0]
-    .menu add cascade -label File -menu $m -underline 0
+    .menu add cascade -label [mc "File"] -menu $m -underline 0
 
     $m add command -underline 0 \
 	-accel {Ctrl+b} \
-	-label [set label [M {Batch File}]] \
+	-label [set label [M [mc "Batch File"]]] \
 	-command [set command [cIDECreateEvent $text $label {
-	    set file [tide_openfile [M "Open a file to Batch"] "" *.mac]
+	    set file [tide_openfile [M [mc "Open a file to Batch"]] "" *.mac]
 	    if {$file != ""} {
-		sendMaxima $maxima_priv(cConsoleText) "BATCH(\"$file\")\$\n"
+		sendMaxima $maxima_priv(cConsoleText) "batch(\"$file\")\$\n"
 	    }
 	}]]
     bind $text <Control-Key-b> $command
 
     $m add command -underline 11 \
 	-accel {Ctrl+o} \
-	-label [set label [M {Batch File Silently}]] \
+	-label [set label [M [mc "Batch File Silently"]]] \
 	-command [set command [cIDECreateEvent $text $label {
-	    set file [tide_openfile [M "Open a file to BATCHLOAD"] "" *.mac]
+	    set file [tide_openfile [M [mc "Open a file to Batch Silently"]] "" *.mac]
 	    if {$file != ""} {
-		sendMaxima $maxima_priv(cConsoleText) "BATCHLOAD(\"$file\")\$\n"
+		sendMaxima $maxima_priv(cConsoleText) "batchload(\"$file\")\$\n"
 	    }
 	}]]
     bind $text <Control-Key-o> $command
 
     $m add separator
     $m add command -underline 0 \
-	-label [set label {Save Expressions to File}] \
+	-label [set label [mc "Save Expressions to File"]] \
 	-accel {Ctrl+s} \
 	-command [set command [cIDECreateEvent $text $label {
-	    set file [tide_savefile [M "Save to a file"] "" *.bin]
+	    set file [tide_savefile [M [mc "Save to a file"]] "" *.bin]
 	    if {$file != ""} {
-		sendMaxima $maxima_priv(cConsoleText) "SAVE(\"$file\",ALL)\$\n"
+		sendMaxima $maxima_priv(cConsoleText) "save(\"$file\",all)\$\n"
 	    }
 	}]]
     bind $text <Control-Key-s> $command
@@ -68,66 +68,66 @@ proc vMAXAddSystemMenu {fr text} {
 
     $m add sep
     $m add command -underline 0 \
-	-label {Interrupt} \
+	-label [mc "Interrupt"] \
 	-accel {Ctrl+g} \
 	-command [list event generate $text <Control-Key-g>]
     $m add command -underline 0 \
-	-label {Restart} \
+	-label [mc "Restart"] \
 	-command [list runOneMaxima $text]
 
     $m add separator
     $m add command -underline 1 \
-	-label {Exit} \
+	-label [mc "Exit"] \
 	-command [list tkmaxima exit $text]
 
     # Add a Edit menubutton
     set m [menu .menu.edit -tearoff 0]
-    .menu add cascade -label Edit -menu $m -underline 0
+    .menu add cascade -label [mc "Edit"] -menu $m -underline 0
 
     $m add command -underline 2 \
-	-label {Cut} \
+	-label [mc "Cut"] \
 	-accel {Ctrl+x} \
 	-command [list event generate $text <Control-Key-x>]
     $m add command -underline 0 \
-	-label {Copy} \
+	-label [mc "Copy"] \
 	-accel {Ctrl+c} \
 	-command [list event generate $text <Control-Key-c>]
     $m add command -underline 0 \
-	-label {Paste} \
+	-label [mc "Paste"] \
 	-accel {Ctrl+v} \
 	-command [list event generate $text <Control-Key-v>]
     #mike distinguish from Cut/Copy/Past and Kill/Yank
     $m add separator
     $m add command -underline 0 \
-	-label {Kill} \
+	-label [mc "Kill"] \
 	-accel {Ctrl+k} \
 	-command [list event generate $text <Control-Key-k>]
     $m add command -underline 0 \
-	-label {Yank} \
+	-label [mc "Yank"] \
 	-accel {Ctrl+y} \
 	-command [list event generate $text <Control-Key-y>]
     $m add separator
     #mike FIXME: use event generate
     $m add command -underline 0 \
-	-label {Previous Input} \
+	-label [mc "Previous Input"] \
 	-accel {Alt-p} \
 	-command [list CNpreviousInput $text -1]
     $m add command -underline 0 \
-	-label {Next Input} \
+	-label [mc "Next Input"] \
 	-accel {Alt-n} \
 	-command [list CNpreviousInput $text 1]
-    $m add command -underline 9 -label {Clear input} \
+    $m add command -underline 9 -label [mc "Clear input"] \
 	-accel {Ctrl+u} \
 	-command [list CNclearinput $text]
     $m add separator
-    $m add command -underline 0 -label {Save Console to File} \
+    $m add command -underline 0 -label [mc "Save Console to File"] \
 	-command [list pMAXSaveTexToFile $maxima_priv(cConsoleText)]
 
     # Add a Options menubutton
     set m [menu .menu.options -tearoff 0]
-    .menu add cascade -label Options -menu $m -underline 0
+    .menu add cascade -label [mc "Options"] -menu $m -underline 0
 
-    $m add command -underline 0 -label {Toggle Browser Visibility} \
+    $m add command -underline 0 -label [mc "Toggle Browser Visibility"] \
 	-command {
 	    #mike FIXME: hard coding
 	    if { [catch { pack info .browser }] } {
@@ -139,37 +139,37 @@ proc vMAXAddSystemMenu {fr text} {
 
     $m add separator
     set pm [menu $m.plot]
-    $m add cascade -label "Plot Windows" -menu $pm
+    $m add cascade -label [mc "Plot Windows"] -menu $pm
     foreach elt { embedded separate multiple } {
-	$pm add radio -label [string totit $elt] \
+	$pm add radio -label [mc [string totit $elt]] \
 	    -variable maxima_default(plotwindow) \
 	    -value $elt
     }
 
     $m add separator
     $m add command -underline 0 \
-	-label {Preferences} \
+	-label [mc "Preferences"] \
 	-command {fontDialog .preferences}
     if {[info commands console] == "console" } {
 	$m add sep
-	$m add command -underline 0 -label "Show Tcl Console" \
+	$m add command -underline 0 -label [mc "Show Tcl Console"] \
 	    -command [list console show]
     }
 
     # Add a Maxima menubutton
     set m [menu .menu.maxima -tearoff 0]
-    .menu add cascade -label Maxima -menu $m -underline 0
+    .menu add cascade -label "Maxima" -menu $m -underline 0
 
     set km [menu $m.kill]
-    $m add cascade -label "Clear Memory" -menu $km
-    $km add command -label "Kill All" \
-	-command [list sendMaxima $text "KILL(ALL)\$\n"]
+    $m add cascade -label [mc "Clear Memory"] -menu $km
+    $km add command -label [mc "Kill All"] \
+	-command [list sendMaxima $text "kill(all)\$\n"]
     $km add separator
-    foreach elt {LABELS VALUES FUNCTIONS MACROS ARRAYS \
-		     MYOPTIONS PROPS ALIASES RULES GRADEFS \
-		     DEPENDENCIES LET_RULE_PACKAGES} {
+    foreach elt {labels values functions macros arrays \
+		     myoptions props aliases rules gradefs \
+		     dependencies let_rule_packages} {
 	$km add command -label "Kill [string totit $elt]" \
-	    -command [list sendMaxima $text "KILL($elt)\$\n"]
+	    -command [list sendMaxima $text "kill($elt)\$\n"]
     }
     $m add separator
     set dir $maxima_priv(pTestsDir)
@@ -180,13 +180,13 @@ proc vMAXAddSystemMenu {fr text} {
     }
     $m add command -underline 0 \
 	-state $state \
-	-label {Run Tests} \
+	-label [mc "Run Tests"] \
 	-command [list sendMaxima $text "run_testsuite()\$\n"]
 
 
     # Add a Help menubutton
     set m [menu .menu.help -tearoff 0]
-    .menu add cascade -label Help -menu $m -underline 0
+    .menu add cascade -label [mc "Help"] -menu $m -underline 0
 
     set file $maxima_priv(pReferenceToc)
     if {[file isfile $file]} {
@@ -199,7 +199,7 @@ proc vMAXAddSystemMenu {fr text} {
     } else {
 	set state disabled
     }
-    $m add command -underline 7 -label {Maxima Help} \
+    $m add command -underline 7 -label [mc "Maxima Help"] \
 	-state $state \
 	-command "OpenMathOpenUrl \"file:/$file\""
     set browse {exec}
@@ -214,15 +214,22 @@ proc vMAXAddSystemMenu {fr text} {
 	    lappend browse cmd.exe /c start
 	}
     } else {
-	# This is more difficult under Unix - KDE GNOME CDE etc...
-	lappend browse netscape
+	
+	set selectedbrowser mozilla
+
+	foreach b { mozilla konqueror epiphany firefox netscape } {
+	    if { ! [catch {exec which $b} ] } {
+		set selectedbrowser $b
+		break } }
+
+	lappend browse $selectedbrowser
     }
     $m add sep
-    $m add command -underline 0 -label {Maxima Homepage} \
+    $m add command -underline 0 -label [mc "Maxima Homepage"] \
 	-command [list eval $browse http://maxima.sourceforge.net &]
-    $m add command -underline 0 -label {Project Page} \
+    $m add command -underline 0 -label [mc "Project Page"] \
 	-command [list eval $browse http://sourceforge.net/projects/maxima &]
-    $m add command -underline 0 -label {Bug Reports} \
+    $m add command -underline 0 -label [mc "Bug Reports"] \
 	-command [list eval $browse \
 		      {http://sourceforge.net/tracker/?group_id=4933&atid=104933} &]
 
