@@ -32,51 +32,51 @@
 ;;; simultaneously of type (1) and (1m).
 
 (defun $listarray (ary)
-       (Cons '(mlist)
-	     (cond ((mget ary 'hashar)
-		    (mapcar #'(lambda (subs) ($arrayapply ary subs))
-			    (cdddr (meval (list '($arrayinfo) ary)))))
-		   ((mget ary 'array) (listarray (mget ary 'array)))
-		   #+cl
-		   ((arrayp ary) (coerce ary 'list))
-		   #+cl
-  		   ( 
-		    (hash-table-p ary)
-		    (let (vals (tab ary))
-		      (declare (special vals tab))
-		       (maphash #'(lambda (x &rest l)l (push (gethash x tab) vals)) ary )
-		       vals))
-		   (t 
-		    (merror "Argument to LISTARRAY must be an array:~%~M" ary)))))
+  (cons '(mlist)
+	(cond ((mget ary 'hashar)
+	       (mapcar #'(lambda (subs) ($arrayapply ary subs))
+		       (cdddr (meval (list '($arrayinfo) ary)))))
+	      ((mget ary 'array) (listarray (mget ary 'array)))
+	      #+cl
+	      ((arrayp ary) (coerce ary 'list))
+	      #+cl
+	      ( 
+	       (hash-table-p ary)
+	       (let (vals (tab ary))
+		 (declare (special vals tab))
+		 (maphash #'(lambda (x &rest l)l (push (gethash x tab) vals)) ary )
+		 vals))
+	      (t 
+	       (merror "Argument to `listarray' must be an array:~%~M" ary)))))
 
 (defmfun $fillarray (ary1 ary2)
-      (let ((ary
-	      (or
-	       (mget ary1 'array)
-	       #+cl
-	       (and (arrayp ary1) ary1)
-	       (merror "First argument to FILLARRAY must be a declared array:~%~M" ary1))))
-	    (fillarray
-	     ary
-	     (cond (($listp ary2) (cdr ary2))
-		   ((get (mget ary2 'array) 'array))
-		   #+cl
-		   ((arrayp ary2) ary2)
-		   (t
-		    (merror
-		     "Second argument to FILLARRAY must be an array or list:~%~M" ary2))))
-	    ary1))
-;#+cl
-;(defmacro $rearray (ar &rest dims)
-;  `(cond ($use_fast_arrays (setq ,ar (rearray-aux ',ar ,(safe-value ar) ,@ dims)))
-;	 (t (rearray-aux ',ar (safe-value ,ar) ,@ dims))))
+  (let ((ary
+	 (or
+	  (mget ary1 'array)
+	  #+cl
+	  (and (arrayp ary1) ary1)
+	  (merror "First argument to `fillarray' must be a declared array:~%~M" ary1))))
+    (fillarray
+     ary
+     (cond (($listp ary2) (cdr ary2))
+	   ((get (mget ary2 'array) 'array))
+	   #+cl
+	   ((arrayp ary2) ary2)
+	   (t
+	    (merror
+	     "Second argument to `fillarray' must be an array or list:~%~M" ary2))))
+    ary1))
+;;#+cl
+;;(defmacro $rearray (ar &rest dims)
+;;  `(cond ($use_fast_arrays (setq ,ar (rearray-aux ',ar ,(safe-value ar) ,@ dims)))
+;;	 (t (rearray-aux ',ar (safe-value ,ar) ,@ dims))))
 
 (defun getvalue (sym)
   (and (symbolp sym) (boundp sym) (symbol-value sym)))
 (defmspec $rearray (l) (setq l (cdr l))
-  (let ((ar (car l)) (dims (cdr l)))
-    (cond ($use_fast_arrays (set ar (rearray-aux ar (getvalue ar) dims )))
-	  (t (rearray-aux ar (getvalue ar) dims)))))
+	  (let ((ar (car l)) (dims (cdr l)))
+	    (cond ($use_fast_arrays (set ar (rearray-aux ar (getvalue ar) dims )))
+		  (t (rearray-aux ar (getvalue ar) dims)))))
 
 #+cl
 (defun rearray-aux (ar val dims &aux marray-sym)
@@ -92,24 +92,24 @@
 #-cl
 (defmspec $rearray (l) (setq l (cdr l))
 	  (cond ((> (length l) 6)
-		 (merror "Too many arguments to REARRAY:~%~M" l))
+		 (merror "Too many arguments to `rearray':~%~M" l))
 		((< (length l) 2)
-		 (merror "Too few arguments to REARRAY:~%~M" l)))
+		 (merror "Too few arguments to `rearray':~%~M" l)))
 	  (let ((name (car l))
 		(ary (cond ($use_fast_arrays
-			   (symbol-value (car l)))
-		     (t
-		       (cond ((mget (car l) 'array))
-			     (t 
-			      (merror "First argument to REARRAY must be a declared array:~%~M"
-				      (car l))))))))
+			    (symbol-value (car l)))
+			   (t
+			    (cond ((mget (car l) 'array))
+				  (t 
+				   (merror "First argument to `rearray' must be a declared array:~%~M"
+					   (car l))))))))
 	    (setq l (cdr l)
 		  l (mapcar #'(lambda (x)
 				(setq x (meval x))
 				(cond ((not (eq (ml-typep x) 'fixnum))
 				       (merror
-					 "Non-integer dimension to REARRAY:~%~M"
-					 x)))
+					"Non-integer dimension to `rearray':~%~M"
+					x)))
 				#-cl
 				(f1+ x)
 				#+cl x
@@ -118,9 +118,9 @@
 	    (show l)
 	    #-lispm
 	    (let ((new-array 
-		    (apply '*rearray (cons ary 
-					   (cons (car (arraydims ary)) l)))))
-	      #+Franz(mputprop name new-array 'array)
+		   (apply '*rearray (cons ary 
+					  (cons (car (arraydims ary)) l)))))
+	      #+franz(mputprop name new-array 'array)
 	      )
 	    #+lispm
 	    (progn
@@ -132,50 +132,50 @@
 	    name))
 
 
-;(defmspec $rearray (l) (setq l (cdr l))
-;	  (cond ((> (length l) 6)
-;		 (merror "Too many arguments to REARRAY:~%~M" l))
-;		((< (length l) 2)
-;		 (merror "Too few arguments to REARRAY:~%~M" l)))
-;	  (let ((name (car l))
-;		(ary (cond ($use_fast_arrays
-;			   (symbol-value (car l)))
-;		     (t
-;		       (cond ((mget (car l) 'array))
-;			     (t 
-;			      (merror "First argument to REARRAY must be a declared array:~%~M"
-;				      (car l))))))))
-;	    (setq l (cdr l)
-;		  l (mapcar #'(lambda (x)
-;				(setq x (meval x))
-;				(cond ((not (eq (ml-typep x) 'fixnum))
-;				       (merror
-;					 "Non-integer dimension to REARRAY:~%~M"
-;					 x)))
-;				#-lispm
-;				(f1+ x)
-;				#+Lispm x
-;				)
-;			    l))
-;	    (show l)
-;	    #-lispm
-;	    (let ((new-array 
-;		    (apply '*rearray (cons ary 
-;					   (cons (car (arraydims ary)) l)))))
-;	      #+Franz(mputprop name new-array 'array)
-;	      )
-;	    #+lispm
-;	    (progn
-;	      (cond ($use_fast_arrays
-;		     (setq ary (apply 'lispm-rearray (cons ary l))))
-;		    (t (setf (symbol-function ary) (apply 'lispm-rearray (cons (symbol-function ary) l)))))
-;	      (cond ($use_fast_arrays (setq name ary))
-;		    (t (mputprop name ary 'array))))
-;	    name))
+;;(defmspec $rearray (l) (setq l (cdr l))
+;;	  (cond ((> (length l) 6)
+;;		 (merror "Too many arguments to `rearray':~%~M" l))
+;;		((< (length l) 2)
+;;		 (merror "Too few arguments to `rearray':~%~M" l)))
+;;	  (let ((name (car l))
+;;		(ary (cond ($use_fast_arrays
+;;			   (symbol-value (car l)))
+;;		     (t
+;;		       (cond ((mget (car l) 'array))
+;;			     (t 
+;;			      (merror "First argument to `rearray' must be a declared array:~%~M"
+;;				      (car l))))))))
+;;	    (setq l (cdr l)
+;;		  l (mapcar #'(lambda (x)
+;;				(setq x (meval x))
+;;				(cond ((not (eq (ml-typep x) 'fixnum))
+;;				       (merror
+;;					 "Non-integer dimension to `rearray':~%~M"
+;;					 x)))
+;;				#-lispm
+;;				(f1+ x)
+;;				#+Lispm x
+;;				)
+;;			    l))
+;;	    (show l)
+;;	    #-lispm
+;;	    (let ((new-array 
+;;		    (apply '*rearray (cons ary 
+;;					   (cons (car (arraydims ary)) l)))))
+;;	      #+Franz(mputprop name new-array 'array)
+;;	      )
+;;	    #+lispm
+;;	    (progn
+;;	      (cond ($use_fast_arrays
+;;		     (setq ary (apply 'lispm-rearray (cons ary l))))
+;;		    (t (setf (symbol-function ary) (apply 'lispm-rearray (cons (symbol-function ary) l)))))
+;;	      (cond ($use_fast_arrays (setq name ary))
+;;		    (t (mputprop name ary 'array))))
+;;	    name))
 
 #+cl
-;(defun lispm-rearray (ar &rest dims)
-; ( make-array (mapcar '1+ (copy-list dims)) :element-type (array-element-type ar) :displaced-to ar ))
+;;(defun lispm-rearray (ar &rest dims)
+;; ( make-array (mapcar '1+ (copy-list dims)) :element-type (array-element-type ar) :displaced-to ar ))
 
 
 (defun lispm-rearray (ar &rest dims)
