@@ -1,4 +1,5 @@
-;;; Compiled by f2cl version 2.0 beta 2002-05-06
+;;; Compiled by f2cl version 2.0 beta Date: 2005/06/20 01:53:39 
+;;; Using Lisp CMU Common Lisp Snapshot 2005-06 (19B)
 ;;; 
 ;;; Options: ((:prune-labels nil) (:auto-save t) (:relaxed-array-decls t)
 ;;;           (:coerce-assigns :as-needed) (:array-type ':simple-array)
@@ -10,7 +11,7 @@
 
 (defun xercnt (librar subrou messg nerr level kontrl)
   (declare (type f2cl-lib:integer4 kontrl level nerr)
-           (type (simple-array base-char (*)) messg subrou librar))
+           (type (simple-array character (*)) messg subrou librar))
   (prog ()
     (declare)
     (go end_label)
