@@ -1,4 +1,5 @@
-;;; Compiled by f2cl version 2.0 beta 2002-05-06
+;;; Compiled by f2cl version 2.0 beta Date: 2005/06/20 01:53:39 
+;;; Using Lisp CMU Common Lisp Snapshot 2005-06 (19B)
 ;;; 
 ;;; Options: ((:prune-labels nil) (:auto-save t) (:relaxed-array-decls t)
 ;;;           (:coerce-assigns :as-needed) (:array-type ':simple-array)
@@ -8,8 +9,7 @@
 (in-package "SLATEC")
 
 
-;; If we get a SLATEC error, print out the message and signal a Maxima
-;; error.  Should we also clear out the error message summary that
-;; SLATEC seems to keep?
 (defun xerhlt (messg)
-  (maxima::merror messg))
+  (declare (type (simple-array character (*)) messg))
+  (prog () (declare) end_label (return (values nil))))
+
