@@ -1,4 +1,5 @@
-;;; Compiled by f2cl version 2.0 beta 2002-05-06
+;;; Compiled by f2cl version 2.0 beta Date: 2005/06/20 01:53:39 
+;;; Using Lisp CMU Common Lisp Snapshot 2005-06 (19B)
 ;;; 
 ;;; Options: ((:prune-labels nil) (:auto-save t) (:relaxed-array-decls t)
 ;;;           (:coerce-assigns :as-needed) (:array-type ':simple-array)
@@ -10,8 +11,8 @@
 
 (defun zabs (zr zi)
   (declare (type double-float zi zr))
-  (prog ((u 0.0) (v 0.0) (q 0.0) (s 0.0) (zabs 0.0))
-    (declare (type double-float zabs s q v u))
+  (prog ((u 0.0) (v 0.0) (q 0.0) (s 0.0) (zabs 0.0) (abs$ 0.0f0))
+    (declare (type single-float abs$) (type double-float zabs s q v u))
     (setf u (coerce (abs zr) 'double-float))
     (setf v (coerce (abs zi) 'double-float))
     (setf s (+ u v))
