@@ -6,10 +6,14 @@
 ;;; ("testfile.mac" 7 9 13).
 
 (setf *testsuite-files*
-      '("rtest1.mac" "rtest1a.mac" "rtest2.mac" "rtest4.mac"  "rtest5.mac"
+      '("rtestnset.mac" "rtest1.mac" "rtest1a.mac" "rtest2.mac" "rtest4.mac"  "rtest5.mac"
 	"rtest6.mac" "rtest6a.mac" "rtest6b.mac" "rtest7.mac" "rtest9.mac"
 	"rtest9a.mac" "rtest10.mac" "rtest11.mac" "rtest13.mac" "rtest13s.mac"
-	"rtest14.mac" 
+	("rtest14.mac" 57 63)
 	("rtest15.mac" 4)
-	"rtestode.mac" "rtestode_zp.mac" "rtestflatten.mac"
-	"rtest3.mac" "rtest8.mac" "rtest12.mac" "rexamples.mac"))
\ No newline at end of file
+	("rtest16.mac" 5)
+	"rtestode.mac" "rtestode_zp.mac"
+	"rtest3.mac" "rtest8.mac" "rtest12.mac" "rexamples.mac"
+	"rtesthyp.mac"
+    "rtestmt19937.mac"
+	))
